@@ -1,2 +1,4 @@
-from python_hackrf.libhackrf import pyhackrf
+__version__ = '1.0.7'
+
+from python_hackrf.pylibhackrf import pyhackrf
 from python_hackrf.pyhackrf_tools import pyhackrf_info, pyhackrf_sweep
