@@ -2,7 +2,8 @@ from .pyhackrf_tools import pyhackrf_info, pyhackrf_sweep
 from .pylibhackrf import pyhackrf
 import argparse
 
-if __name__ == '__main__':
+
+def main():
     parser = argparse.ArgumentParser(
         description="python_hackrf is a Python wrapper for libhackrf and hackrf-tools.",
         usage="python -m python_hackrf [-h] {info, sweep} ..."
@@ -34,42 +35,49 @@ if __name__ == '__main__':
     pyhackrf_sweep_parser.add_argument('-r', action='store', help='filename. output file', metavar='')
     args, unparsed_args = parser.parse_known_args()
 
-    if args.command == 'info':
-        if args.serial_numbers:
-            pyhackrf_info.pyhackrf_serial_numbers_list_info()
-        else:
-            pyhackrf_info.pyhackrf_info()
+    if not hasattr(args, 'command'):
+        parser.print_help()
+    else:
+        if args.command == 'info':
+            if args.serial_numbers:
+                pyhackrf_info.pyhackrf_serial_numbers_list_info()
+            else:
+                pyhackrf_info.pyhackrf_info()
 
-    if args.command == 'sweep':
-        str_frequencies = args.f.split(',')
-        frequencies = []
-        for frequency_range in str_frequencies:
-            frequency_range = frequency_range.split(':')
-            freq_min, freq_max = None, None
-            try:
-                freq_min = int(frequency_range[0])
-            except Exception:
-                pass
-            try:
-                freq_max = int(frequency_range[1])
-            except Exception:
-                pass
-            if freq_min is not None and freq_max is not None:
-                frequencies.extend([freq_min, freq_max])
+        if args.command == 'sweep':
+            str_frequencies = args.f.split(',')
+            frequencies = []
+            for frequency_range in str_frequencies:
+                frequency_range = frequency_range.split(':')
+                freq_min, freq_max = None, None
+                try:
+                    freq_min = int(frequency_range[0])
+                except Exception:
+                    pass
+                try:
+                    freq_max = int(frequency_range[1])
+                except Exception:
+                    pass
+                if freq_min is not None and freq_max is not None:
+                    frequencies.extend([freq_min, freq_max])
 
-        pyhackrf_sweep.pyhackrf_sweep(frequencies=frequencies,
-                                      lna_gain=int(args.l),
-                                      vga_gain=int(args.g),
-                                      bin_width=int(args.w),
-                                      serial_number=args.d,
-                                      amp_enable=args.a,
-                                      antenna_enable=args.p,
-                                      num_sweeps=int(args.N) if args.N is not None else None,
-                                      binary_output=args.B,
-                                      one_shot=args.__dict__.get('1'),
-                                      filename=args.r,
-                                      sweep_style=pyhackrf.py_sweep_style.LINEAR if args.s == 'L' else pyhackrf.py_sweep_style.INTERLEAVED,
-                                      sample_rate=int(args.SR) * 1e6,
-                                      baseband_filter=float(args.BF) * 1e6,
-                                      print_to_console=True,
-                                      )
+            pyhackrf_sweep.pyhackrf_sweep(frequencies=frequencies,
+                                        lna_gain=int(args.l),
+                                        vga_gain=int(args.g),
+                                        bin_width=int(args.w),
+                                        serial_number=args.d,
+                                        amp_enable=args.a,
+                                        antenna_enable=args.p,
+                                        num_sweeps=int(args.N) if args.N is not None else None,
+                                        binary_output=args.B,
+                                        one_shot=args.__dict__.get('1'),
+                                        filename=args.r,
+                                        sweep_style=pyhackrf.py_sweep_style.LINEAR if args.s == 'L' else pyhackrf.py_sweep_style.INTERLEAVED,
+                                        sample_rate=int(args.SR) * 1e6,
+                                        baseband_filter=float(args.BF) * 1e6,
+                                        print_to_console=True,
+                                        )
+
+
+if __name__ == '__main__':
+    main()
